/************************************************************************************
ButtonConverter RT-Component
Copyright (c) 2010, Kyoto Uni.
All rights reserved.

Contact us if you use this software for sell.
If you use this software not for sell, you can use this software under BSD lisence.
See the files LICENSE.TXT and LICENSE-BSD.TXT for more details.                     
************************************************************************************/
// -*- C++ -*-
/*!
 * @file  ButtonConverter.cpp
 * @brief Gampad button data to boolean
 * @date $Date$
 *
 * $Id$
 */

#include "ButtonConverter.h"

// Module specification
// <rtc-template block="module_spec">
static const char* buttonconverter_spec[] =
  {
    "implementation_id", "ButtonConverter",
    "type_name",         "ButtonConverter",
    "description",       "Gampad button data to boolean",
    "version",           "1.0.0",
    "vendor",            "VenderName",
    "category",          "Generic",
    "activity_type",     "PERIODIC",
    "kind",              "DataFlowComponent",
    "max_instance",      "0",
    "language",          "C++",
    "lang_type",         "compile",
	"config.default.buttonNum_Manual", "1",
	"config.default.buttonNum_Auto", "2",
    ""
  };
// </rtc-template>

/*!
 * @brief constructor
 * @param manager Maneger Object
 */
ButtonConverter::ButtonConverter(RTC::Manager* manager)
    // <rtc-template block="initializer">
  : RTC::DataFlowComponentBase(manager),
    m_buttonIn("button", m_button),
    m_doAutoOut("doAuto", m_doAuto)

    // </rtc-template>
{
}

/*!
 * @brief destructor
 */
ButtonConverter::~ButtonConverter()
{
}



RTC::ReturnCode_t ButtonConverter::onInitialize()
{
  // Registration: InPort/OutPort/Service
  // <rtc-template block="registration">
  // Set InPort buffers
  addInPort("button", m_buttonIn);
  
  // Set OutPort buffer
  addOutPort("doAuto", m_doAutoOut);
  
  // Set service provider to Ports
  
  // Set service consumers to Ports
  
  // Set CORBA Service Ports
  
  bindParameter("buttonNum_Manual",m_buttonNum_Manual,"1");
  bindParameter("buttonNum_Auto",m_buttonNum_Auto,"2");
  m_configsets.update("default");  
  // </rtc-template>

  return RTC::RTC_OK;
}

/*
RTC::ReturnCode_t ButtonConverter::onFinalize()
{
  return RTC::RTC_OK;
}
*/

/*
RTC::ReturnCode_t ButtonConverter::onStartup(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/

/*
RTC::ReturnCode_t ButtonConverter::onShutdown(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/


RTC::ReturnCode_t ButtonConverter::onActivated(RTC::UniqueId ec_id)
{
	m_doAuto.data = false;
	m_doAutoOut.write();
  return RTC::RTC_OK;
}


/*
RTC::ReturnCode_t ButtonConverter::onDeactivated(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/


RTC::ReturnCode_t ButtonConverter::onExecute(RTC::UniqueId ec_id)
{
	if ( m_buttonIn.isNew() )
	{
		m_buttonIn.read();
	
		if ( m_button.data == m_buttonNum_Auto )
		{
			m_doAuto.data = true;
			m_doAutoOut.write();
		}

		if ( m_button.data == m_buttonNum_Manual )
		{
			m_doAuto.data = false;
			m_doAutoOut.write();
		}
	}
	return RTC::RTC_OK;
}


/*
RTC::ReturnCode_t ButtonConverter::onAborting(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/

/*
RTC::ReturnCode_t ButtonConverter::onError(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/

/*
RTC::ReturnCode_t ButtonConverter::onReset(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/

/*
RTC::ReturnCode_t ButtonConverter::onStateUpdate(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/

/*
RTC::ReturnCode_t ButtonConverter::onRateChanged(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/



extern "C"
{
 
  void ButtonConverterInit(RTC::Manager* manager)
  {
    coil::Properties profile(buttonconverter_spec);
    manager->registerFactory(profile,
                             RTC::Create<ButtonConverter>,
                             RTC::Delete<ButtonConverter>);
  }
  
};


