/************************************************************************************
DeviceControl RT-Component
Copyright (c) 2010, Kyoto Uni.
All rights reserved.

Contact us if you use this software for sell.
If you use this software not for sell, you can use this software under BSD lisence.
See the files LICENSE.TXT and LICENSE-BSD.TXT for more details.                     
************************************************************************************/

/***********************************************************************************/
/*!
*	@file Dacs2600.h
*	@brief Class for Dacs2600
*	@author kazuyuki kon@ Kyoto-u
*/
/***********************************************************************************/
#ifndef __Dacs2600_H
#define __Dacs2600_H


#include "CSerial.h"
#include <stdio.h>
#include <stdlib.h>
#include <math.h>
#include <string.h>
#include <iostream>
#include <vector>


using namespace std;

const int LIGHT_GREEN  = 0; //!< GREEN
const int LIGHT_ORANGE = 1; //!< ORANGE
const int LIGHT_RED    = 2; //!< RED

const int EMO = 0;	//!< command to get data from dacs2600


/***********************************************************************************/
/*!
*	@class Dacs2600
*/
/***********************************************************************************/

class Dacs2600
{
public:

	/*!
	*	@brief Dafault constructor
	*/
	Dacs2600();			
	
	/*!
	*	@brief Destructor
	*/
	~Dacs2600();

	/*!
	*	@brief initialize serial port
	* 	@param[in] portname Name of serial port
	*/
	bool initialize(std::string _portname);		

	/*!
	*	@brief initialize serial port
	* 	@param[in] portname Name of serial port
	*	@param[in] baudrate
	*/	
	bool initialize(std::string _portname,int _baudrate);	

	/*!
	*	@brief terminate serial communication
	*/
   	void terminate(void);	

	/*!
	*	@brief Send & Get data
	* 	@retval 
	*/
	bool update(void);		

	/*!
	*	@brief Change patolight mode
	* 	@retval 
	*/
	void setLightMode(int mode);	

	/*!
	*	@brief Change patolight mode
	* 	@retval 
	*/
	void setLightMode2(int mode);

	/*!
	*	@brief 
	* 	@retval 
	*/
	bool getEMOStatus(void);	 

	/*!
	*	@brief 
	* 	@retval 
	*/
	bool getConnectionStatus();

private: 

	CSerial serial;		//!< serial comunication class object
	bool isConnect;		//!< connection status
	int baudrate[8];	//!< baudrate
	
    unsigned char command[1];	//!< command to send
	char status[1];				//!< status
	char setbit[8];				//!<

protected:


};

#endif
